// Copyright (c) 2006 David Drysdale.  See license.txt for license info
import java.awt.*;

class LetterCanvas extends Canvas {
  private int[] missedCount;
  private int[] totalCount;
  public LetterCanvas() {}
  public void paintBackground(Graphics g) {
    Dimension d = getSize();
    g.setColor(Color.gray);
    g.fillRect(0,0,d.width,d.height);
    g.setFont(new Font("Helvetica", Font.BOLD, 150));
  }
  public void displayData(int[] m, int[] t) {
    // Store the data so we can repaint asynchronously
    missedCount = m;
    totalCount = t;

    // Figure out Y scale
    Dimension d = getSize();
    int maxnum = -1;
    for (int dd=1; dd<20; dd++) {
      if (totalCount[dd] > maxnum) maxnum=totalCount[dd];
    }
    if (maxnum <= 0) return;
    int yscale = (int)Math.floor(d.height/maxnum);
    Graphics g = getGraphics();
    // First draw the totals
    g.setColor(Color.white);
    for (int dd=0; dd<20; dd++) {
      g.fillRect(((dd*d.width)/20), d.height - (yscale*totalCount[dd]),
                 (d.width/20), yscale*totalCount[dd]);
    }
    // Now draw the missed
    g.setColor(Color.black);
    for (int dd=0; dd<20; dd++) {
      g.fillRect(((dd*d.width)/20), d.height - (yscale*missedCount[dd]),
                 (d.width/20), yscale*missedCount[dd]);
    }
  }
  public void paint(Graphics g) {
    paintBackground(g);
    if (totalCount != null) displayData(missedCount, totalCount);
  }
  public void clearData() {
    totalCount = null;
    missedCount = null;
    paintBackground(getGraphics());
  }
}
